==> karnak-3.0.4-py3-none-any.whl: karnak3/cloud/aws/sqs.py <==
import threading
from typing import Optional, List, Dict, Any
import boto3

import karnak3.core.log as kl


_client_lock = threading.RLock()
_logger = kl.KLog(__name__)


# TODO REMOVE
def log_test():
    _logger.warn('warn-ok')


def get_client():
    with _client_lock:
        return boto3.client('sqs')


def get_queue_url(queue_name: str, sqs_client=None) -> (str, Any):
    if sqs_client is None:
        sqs_client = get_client()
    response = sqs_client.get_queue_url(QueueName=queue_name)
    return response['QueueUrl'], sqs_client


def remove_message(queue_name: str, receipt_handle: str, sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    sqs_client.delete_message(QueueUrl=queue_url, ReceiptHandle=receipt_handle)


def remove_messages(queue_name: str, receipt_handles: List[str], sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    chunks = [receipt_handles[i:i+10] for i in range(0, len(receipt_handles), 10)]
    for chunk in chunks:
        entries = [{'Id': str(i), 'ReceiptHandle': chunk[i]} for i in range(0, len(chunk))]
        sqs_client.delete_message_batch(QueueUrl=queue_url, Entries=entries)


def return_message(queue_name: str, receipt_handle: str, sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    sqs_client.change_message_visibility(QueueUrl=queue_url, ReceiptHandle=receipt_handle,
                                         VisibilityTimeout=0)


def return_messages(queue_name: str, receipt_handles: List[str], sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    # TODO implement batch version
    for receipt_handle in receipt_handles:
        sqs_client.return_message(QueueUrl=queue_url, ReceiptHandle=receipt_handle)


def send_messages(queue_name: str,
                  messages: list,
                  group_id: Optional[str] = None,
                  sqs_client=None) -> list:
    """
    Returns: list os failed ids
    """
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    failed_ids = []
    messages_list = messages.copy()
    ids = list(range(len(messages_list)))
    while len(messages_list) > 0:
        # prepare a batch of up to 10 messages
        batch_items = []
        while len(messages_list) > 0 and len(batch_items) < 10:
            item = {'Id': str(ids.pop(0)), 'MessageBody': messages_list.pop(0)}
            if group_id is not None:
                item['MessageGroupId'] = group_id
            batch_items.append(item)
        result = sqs_client.send_message_batch(QueueUrl=queue_url, Entries=batch_items)
        if result.get('Failed'):
            failed_ids.extend([int(item['Id']) for item in result.get('Failed')])
    failed_messages = [messages[i] for i in failed_ids]
    return failed_messages


def receive_messages(queue_name: str,
                     max_messages: int = 10,
                     wait_seconds: int = 0,
                     sqs_client=None) -> Dict[(str, str)]:
    """Returns a dict of {message_handle: body}"""
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)

    remaining_messages = max_messages
    result_messages = {}

    while remaining_messages > 0:
        request_messages = min(10, remaining_messages)
        result = sqs_client.receive_message(QueueUrl=queue_url,
                                            MaxNumberOfMessages=request_messages,
                                            WaitTimeSeconds=wait_seconds)
        remaining_messages -= request_messages
        if result.get('Messages'):
            new_results = {m['ReceiptHandle']: m['Body'] for m in result['Messages']}
            result_messages.update(new_results)
            # _logger.trace(f'sqs: {len(new_results)} messages read from {queue_name}')
        else:
            # _logger.trace(f'sqs: 0 messages read from {queue_name}')
            break

    _logger.trace(f'sqs: {len(result_messages)} messages read from {queue_name}')
    return result_messages


def queue_attributes(queue_name: str, sqs_client=None) -> dict:
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    result = sqs_client.get_queue_attributes(QueueUrl=queue_url, AttributeNames=['All'])
    return result['Attributes']


def purge_queue(queue_name: str, sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    result = sqs_client.purge_queue(QueueUrl=queue_url)

==> karnak-3.1.4-py3-none-any.whl: karnak3/cloud/aws/sqs.py <==
import threading
from typing import Optional, List, Dict, Any
import boto3

import karnak3.core.log as kl


_client_lock = threading.RLock()
_logger = kl.KLog(__name__)

queue_cache: Dict[str, str] = {}


# TODO REMOVE
def log_test():
    _logger.warn('warn-ok')


def get_client():
    with _client_lock:
        return boto3.client('sqs')


def get_queue_url(queue_name: str, sqs_client=None, use_cache: bool = True) -> (str, Any):
    if sqs_client is None:
        sqs_client = get_client()
    queue_url = queue_cache.get(queue_name) if use_cache else None
    if queue_url is None:
        response = sqs_client.get_queue_url(QueueName=queue_name)
        queue_url = response['QueueUrl']
    response = sqs_client.get_queue_url(QueueName=queue_name)
    return queue_url, sqs_client


def remove_message(queue_name: str, receipt_handle: str, sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    sqs_client.delete_message(QueueUrl=queue_url, ReceiptHandle=receipt_handle)


def remove_messages(queue_name: str, receipt_handles: List[str], sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    chunks = [receipt_handles[i:i+10] for i in range(0, len(receipt_handles), 10)]
    for chunk in chunks:
        entries = [{'Id': str(i), 'ReceiptHandle': chunk[i]} for i in range(0, len(chunk))]
        sqs_client.delete_message_batch(QueueUrl=queue_url, Entries=entries)


def return_message(queue_name: str, receipt_handle: str, sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    sqs_client.change_message_visibility(QueueUrl=queue_url, ReceiptHandle=receipt_handle,
                                         VisibilityTimeout=0)


def return_messages(queue_name: str, receipt_handles: List[str], sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    # TODO implement batch version
    for receipt_handle in receipt_handles:
        sqs_client.return_message(QueueUrl=queue_url, ReceiptHandle=receipt_handle)


def send_messages(queue_name: str,
                  messages: list,
                  group_id: Optional[str] = None,
                  sqs_client=None) -> list:
    """
    Returns: list os failed ids
    """
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    failed_ids = []
    messages_list = messages.copy()
    ids = list(range(len(messages_list)))
    while len(messages_list) > 0:
        # prepare a batch of up to 10 messages
        batch_items = []
        while len(messages_list) > 0 and len(batch_items) < 10:
            item = {'Id': str(ids.pop(0)), 'MessageBody': messages_list.pop(0)}
            if group_id is not None:
                item['MessageGroupId'] = group_id
            batch_items.append(item)
        result = sqs_client.send_message_batch(QueueUrl=queue_url, Entries=batch_items)
        if result.get('Failed'):
            failed_ids.extend([int(item['Id']) for item in result.get('Failed')])
    failed_messages = [messages[i] for i in failed_ids]
    return failed_messages


def receive_messages(queue_name: str,
                     max_messages: int = 10,
                     wait_seconds: int = 0,
                     sqs_client=None) -> Dict[(str, str)]:
    """Returns a dict of {message_handle: body}"""
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)

    remaining_messages = max_messages
    result_messages = {}

    while remaining_messages > 0:
        request_messages = min(10, remaining_messages)
        result = sqs_client.receive_message(QueueUrl=queue_url,
                                            MaxNumberOfMessages=request_messages,
                                            WaitTimeSeconds=wait_seconds)
        remaining_messages -= request_messages
        if result.get('Messages'):
            new_results = {m['ReceiptHandle']: m['Body'] for m in result['Messages']}
            result_messages.update(new_results)
            # _logger.trace(f'sqs: {len(new_results)} messages read from {queue_name}')
        else:
            # _logger.trace(f'sqs: 0 messages read from {queue_name}')
            break

    _logger.trace(f'sqs: {len(result_messages)} messages read from {queue_name}')
    return result_messages


def queue_attributes(queue_name: str, sqs_client=None) -> dict:
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    result = sqs_client.get_queue_attributes(QueueUrl=queue_url, AttributeNames=['All'])
    return result['Attributes']


def purge_queue(queue_name: str, sqs_client=None):
    queue_url, sqs_client = get_queue_url(queue_name, sqs_client)
    result = sqs_client.purge_queue(QueueUrl=queue_url)
